CliMAF : a Climate Model Assessment Framework
---------------------------------------------

CliMAF doc is available at `Readthedocs
<http://climaf.readthedocs.org/>`_ , which includes `installation instructions <http://climaf.readthedocs.org/en/latest/installing.html>`_

The aim of CliMAF is to allow for an actual, **easy, collaborative development of climate model outputs assessment suites by climate scientists with varied IT background**, and to ultimately share such suites for the benefit of the Climate Science. 

It is basically a scriptable way to process NetCDF `CF compliant
<http://cfconventions.org/>`_ climate model outputs 

CliMAF was designed by Stéphane Sénési, who also developped most of the code before version 2.